@@ -40,6 +40,7 @@ sub DumpFile {
     }
     open my $OUT, "$mode $filename"
       or die "Can't open $filename for writing: $!";
+    binmode($OUT, ':utf8');
     print $OUT Dump(@_);
     close $OUT;
 }
@@ -50,9 +51,10 @@ sub LoadFile {
     my $filename = shift;
     open my $IN, $filename
       or die "Can't open $filename for reading: $!";
+    binmode($IN, ':utf8');
     return Load(do { local $/; <$IN> });
     close $IN;
-}   
+}
 
 sub _yaml_chunk {
   my ($indent, $values) = @_;
@@ -139,7 +141,7 @@ Module::Build::YAML - Provides just enough YAML support so that Module::Build wo
 
 Provides just enough YAML support so that Module::Build works even if YAML.pm is not installed.
 
-Currently, this amounts to the ability to write META.yml files when "perl Build distmeta"
+Currently, this amounts to the ability to write META.yml files when C<perl Build distmeta>
 is executed via the Dump() and DumpFile() functions/methods.
 
 =head1 AUTHOR
